@@ -16,31 +16,37 @@ def test
     :name => "fog-l7-resource-view-1",
     :numMembers => 1,
     :members => [instance1.self_link],
-    :zone => "us-central1-a")
+    :zone => "us-central1-a"
+  )
   resource_view1.add_resources(instance1.self_link)
   resource_view2 = connection.resource_views.create(
     :name => "fog-l7-resource-view-2",
     :numMembers => 1,
     :members => [instance2.self_link],
-    :zone => "us-central1-a")
+    :zone => "us-central1-a"
+  )
   resource_view2.add_resources(instance2.self_link)
   resource_view3 = connection.resource_views.create(
     :name => "fog-l7-resource-view-3",
     :members => [instance3.self_link],
-    :zone => "us-central1-b")
+    :zone => "us-central1-b"
+  )
   resource_view3.add_resources(instance3.self_link)
   backend_service1 = connection.backend_services.create(
     :name => "fog-l7-backend-service-1",
     :health_checks => [health.self_link],
-    :backends => [{ "balancingMode" => "RATE", "maxRate" => 100, "group" => resource_view1.self_link }])
+    :backends => [{ "balancingMode" => "RATE", "maxRate" => 100, "group" => resource_view1.self_link }]
+  )
   backend_service2 = connection.backend_services.create(
     :name => "fog-l7-backend-service-2",
     :health_checks => [health.self_link],
-    :backends => [{ "balancingMode" => "RATE", "maxRate" => 100, "group" => resource_view2.self_link }])
+    :backends => [{ "balancingMode" => "RATE", "maxRate" => 100, "group" => resource_view2.self_link }]
+  )
   backend_service3 = connection.backend_services.create(
     :name => "fog-l7-backend-service-3",
     :health_checks => [health.self_link],
-    :backends => [{ "balancingMode" => "RATE", "maxRate" => 100, "group" => resource_view3.self_link }])
+    :backends => [{ "balancingMode" => "RATE", "maxRate" => 100, "group" => resource_view3.self_link }]
+  )
   url_map = connection.url_maps.create(
     :name => "fog-l7-url-map",
     :pathMatchers => [{
@@ -62,10 +68,12 @@ def test
       ]
     }],
     :hostRules => [{ "hosts" => ["*"], "pathMatcher" => "pathmatcher" }],
-    :default_service => backend_service1.self_link)
+    :default_service => backend_service1.self_link
+  )
   proxy = connection.target_http_proxies.create(
     :name => "fog-l7-proxy",
-    :url_map => url_map.self_link)
+    :url_map => url_map.self_link
+  )
 
   connection.global_forwarding_rules.create(:name => "fog-l7-fwd-rule", :target => proxy.self_link)
 end
