@@ -15,7 +15,7 @@ def test
     :name => name,
     :size_gb => 10,
     :zone_name => "us-central1-f",
-    :source_image => "debian-8-jessie-v20161215"
+    :source_image => "debian-9-stretch-v20180611"
   )
 
   disk.wait_for { disk.ready? }
