@@ -5,7 +5,7 @@ module Fog
         model Fog::Compute::Google::GlobalForwardingRule
 
         def all(opts = {})
-          data = service.list_global_forwarding_rules(opts).to_h[:items] || []
+          data = service.list_global_forwarding_rules(**opts).to_h[:items] || []
           load(data)
         end
 
