@@ -5,8 +5,9 @@ module Fog
         model Fog::Compute::Google::Project
 
         def get(identity)
-          if project = service.get_project(identity).to_h
-            new(project)
+          if identity
+            project = service.get_project(identity).to_h
+            return new(project)
           end
         rescue ::Google::Apis::ClientError => e
           raise e unless e.status_code == 404
