@@ -26,7 +26,7 @@ module Fog
           data = service.insert_target_instance(identity, zone, options)
           operation = Fog::Compute::Google::Operations.new(:service => service)
                                                       .get(data.name, data.zone)
-          operation.wait_for { !pending? }
+          operation.wait_for { ready? }
           reload
         end
 
