@@ -5,14 +5,17 @@ module Fog
         model Fog::Compute::Google::Zone
 
         def all
-          data = service.list_zones.body["items"] || []
+          data = service.list_zones.to_h[:items] || []
           load(data)
         end
 
         def get(identity)
-          data = service.get_zone(identity).body
-          new(data)
-        rescue Fog::Errors::NotFound
+          if identity
+            zone = service.get_zone(identity).to_h
+            new(zone)
+          end
+        rescue ::Google::Apis::ClientError => e
+          raise e unless e.status_code == 404
           nil
         end
       end
