@@ -13,16 +13,16 @@ module Fog
         def add_instance_group_instances(group_name, zone, instances)
           instances.map! do |instance|
             if instance.start_with?("https:")
-              ::Google::Apis::ComputeV1::InstanceReference.new(:instance => instance)
+              ::Google::Apis::ComputeV1::InstanceReference.new(instance: instance)
             else
               ::Google::Apis::ComputeV1::InstanceReference.new(
-                :instance => "https://www.googleapis.com/compute/#{api_version}/projects/#{@project}/zones/#{zone}/instances/#{instance}\n"
+                instance: "https://www.googleapis.com/compute/#{api_version}/projects/#{@project}/zones/#{zone}/instances/#{instance}\n"
               )
             end
           end
 
           request = ::Google::Apis::ComputeV1::InstanceGroupsAddInstancesRequest.new(
-            :instances => instances
+            instances: instances
           )
           @compute.add_instance_group_instances(
             @project,
