@@ -3,21 +3,16 @@ module Fog
     class Google
       class Mock
         def get_snapshot(_snap_name)
+          # :no-coverage:
           Fog::Mock.not_implemented
+          # :no-coverage:
         end
       end
 
       class Real
         def get_snapshot(snap_name, project = @project)
           raise ArgumentError.new "snap_name must not be nil." if snap_name.nil?
-
-          api_method = @compute.snapshots.get
-          parameters = {
-            "snapshot" => snap_name,
-            "project"  => project
-          }
-
-          request(api_method, parameters)
+          @compute.get_snapshot(project, snap_name)
         end
       end
     end
