@@ -14,8 +14,8 @@ module Fog
                                           page_token: nil, order_by: nil)
           @compute.list_aggregated_machine_types(
             @project,
-            :filter => filter, :max_results => max_results,
-            :page_token => page_token, :order_by => order_by
+            filter: filter, max_results: max_results,
+            page_token: page_token, order_by: order_by
           )
         end
       end
