@@ -12,7 +12,7 @@ module Fog
       class Real
         def remove_target_pool_health_checks(target_pool, region, health_checks)
           health_check_lst = health_checks.map do |hc|
-            ::Google::Apis::ComputeV1::HealthCheckReference.new(:health_check => hc)
+            ::Google::Apis::ComputeV1::HealthCheckReference.new(health_check: hc)
           end
 
           @compute.remove_target_pool_health_check(
@@ -20,7 +20,7 @@ module Fog
             region.split("/")[-1],
             target_pool,
             ::Google::Apis::ComputeV1::RemoveTargetPoolsHealthCheckRequest.new(
-              :health_checks => health_check_lst
+              health_checks: health_check_lst
             )
           )
         end
