@@ -10,10 +10,11 @@ module Fog
         # @param [String] identity Project identity
         # @return [Fog::DNS::Google::Project] Project resource
         def get(identity)
-          if project = service.get_project(identity).body
+          if project = service.get_project(identity).to_h
             new(project)
           end
-        rescue Fog::Errors::NotFound
+        rescue ::Google::Apis::ClientError => e
+          raise e unless e.status_code == 404
           nil
         end
       end
