@@ -27,6 +27,10 @@ module Fog
       GOOGLE_STORAGE_JSON_BASE_URL = "https://www.googleapis.com/storage/".freeze
       GOOGLE_STORAGE_BUCKET_BASE_URL = "https://storage.googleapis.com/".freeze
 
+      # Version of IAM API used for blob signing, see Fog::Storage::GoogleJSON::Real#iam_signer
+      GOOGLE_STORAGE_JSON_IAM_API_VERSION = "v1".freeze
+      GOOGLE_STORAGE_JSON_IAM_API_SCOPE_URLS = %w(https://www.googleapis.com/auth/devstorage.full_control).freeze
+
       # TODO: Come up with a way to only request a subset of permissions.
       # https://cloud.google.com/storage/docs/json_api/v1/how-tos/authorizing
       GOOGLE_STORAGE_JSON_API_SCOPE_URLS = %w(https://www.googleapis.com/auth/devstorage.full_control).freeze
