@@ -12,9 +12,14 @@ class ForwardingRulesFactory < CollectionFactory
     @target_pools.cleanup
   end
 
+  def all
+    @subject.all(region: TEST_REGION)
+  end
+
   def params
-    params = { :name => resource_name,
-               :region => TEST_REGION,
-               :target => @target_pools.create.self_link }
+    { :name => resource_name,
+      :port_range => "80-80",
+      :region => TEST_REGION,
+      :target => @target_pools.create.self_link }
   end
 end
