@@ -12,6 +12,10 @@ class TargetInstancesFactory < CollectionFactory
     @servers.cleanup
   end
 
+  def all
+    @subject.all(zone: TEST_ZONE)
+  end
+
   def params
     { :name => resource_name,
       :zone => TEST_ZONE,
