@@ -3,6 +3,7 @@ require "integration/storage/storage_shared"
 require "securerandom"
 require "base64"
 require "tempfile"
+require "net/http"
 
 class TestStorageRequests < StorageShared
   def test_put_object_string
@@ -33,13 +34,15 @@ class TestStorageRequests < StorageShared
 
   def test_put_object_paperclip
     object_name = new_object_name
-    paperclip_file = OpenStruct.new(:path => some_temp_file,
+    paperclip_file = OpenStruct.new(:path => some_temp_file(binary_file_content),
                                     :content_type => "image/png")
     @client.put_object(some_bucket_name, object_name, paperclip_file, :content_type => "image/png")
 
     object = @client.get_object(some_bucket_name, object_name)
 
     assert_equal(object_name, object[:name])
+    assert_equal(Encoding::ASCII_8BIT, object[:body].encoding)
+    assert_equal(binary_file_content, object[:body])
     assert_equal("image/png", object[:content_type])
   end
 
@@ -93,10 +96,45 @@ class TestStorageRequests < StorageShared
 
     @client.copy_object(some_bucket_name, some_object_name,
                         some_bucket_name, target_object_name)
+
     object = @client.get_object(some_bucket_name, target_object_name)
+
     assert_equal(temp_file_content, object[:body])
   end
 
+  def test_copy_object_predefined_acl
+    target_object_name = new_object_name
+
+    res = @client.copy_object(some_bucket_name, some_object_name,
+                              some_bucket_name, target_object_name, destination_predefined_acl: "publicRead")
+
+    result = @client.get_object(some_bucket_name, target_object_name)
+
+    response = Net::HTTP.get_response(URI(result[:self_link]))
+
+    assert_kind_of(Net::HTTPOK, response)
+  end
+
+  def test_copy_object_with_request_options
+    assert_raises(Google::Apis::AuthorizationError) do
+      target_object_name = new_object_name
+
+      @client.copy_object(some_bucket_name, some_object_name,
+                          some_bucket_name, target_object_name, authorization: false)
+    end
+  end
+
+  def test_copy_object_with_object_property
+    target_object_name = new_object_name
+
+    @client.copy_object(some_bucket_name, some_object_name,
+                        some_bucket_name, target_object_name, content_type: 'text/plain')
+
+    object = @client.get_object(some_bucket_name, target_object_name)
+
+    assert_equal("text/plain", object[:content_type])
+  end
+
   def test_list_objects
     expected_object = some_object_name
 
